PersistedField

Struct PersistedField 

pub struct PersistedField<T, V> { /* private fields */ }
Read, write, and subscribe access to a generated persisted settings field.

Implementations

Source

impl<T, V> PersistedField<T, V>
where T: Clone + Send + Sync + 'static, V: Clone,

pub fn new( handle: SettingsHandle<T>, key: &'static str, getter: Box<dyn for<'a> Fn(&'a T) -> &'a V + Send + Sync + 'static>, mutator: Box<dyn Fn(&mut T, V) + Send + Sync + 'static>, ) -> Self

Creates a persisted field handle.

pub fn get(&self) -> V

Returns the field value from the current settings snapshot.

Source

impl<T, V> PersistedField<T, V>
where T: Clone + Send + Sync + 'static, V: Clone + Serialize,

pub fn set(&self, value: V) -> Result<(), SettingsError>

Persists a new field value and updates the in-memory snapshot.

Source

impl<T, V> PersistedField<T, V>
where T: Clone + Send + Sync + 'static, V: DeserializeOwned + Send + 'static,

pub fn on_change(&self) -> Receiver<V>

Subscribes to typed changes for this field.

The returned channel receives successfully decoded local and external Set events for this field. Deletes, deserialize failures, other keys, and values that cannot be decoded as V are ignored.