pub struct StoredValue(/* private fields */);Implementations
Sourceimpl StoredValue
impl StoredValue
Sourcepub fn encode<T: Serialize>(value: &T) -> Result<StoredValue, SettingsError>
pub fn encode<T: Serialize>(value: &T) -> Result<StoredValue, SettingsError>
Given a reference to a value of type T, return it as a StoredValue instance with the original value JSON encoded.
pub fn decode<T: DeserializeOwned>(&self) -> Result<T, Error>
pub fn as_str(&self) -> &str
Sourcepub fn from_raw(serialized: String) -> StoredValue
pub fn from_raw(serialized: String) -> StoredValue
Wrap a raw, JSON-encoded string as a Stored Value. For use by backends that read pre-serialized values from persistent storage. The caller is responsible for ensuring the string is valid JSON.