Core traits and types for attune - runtime-mutable, persisted, observable configuration.
Structs
- Config
Path Options - Field
Resolve Options - Inputs used to resolve a single read-only config field.
- Noop
Backend - Persist
Resolve Options - Inputs used to resolve a single persisted config field.
- Persisted
Field - Read, write, and subscribe access to a generated persisted settings field.
- Read
Only Field - Read-only access to a generated settings field.
- Settings
Handle - Stored
Value
Enums
- Apply
Result - Backend
Error - Errors returned by storage backends.
- Change
Event - Change
Source - Settings
Error - Errors returned by generated settings loaders, field setters, and config helpers.
Traits
Functions
- decode_
persist_ value - Decodes a persisted value, with an optional legacy fallback parser.
- load_
toml_ file - Loads an optional TOML config file into a table.
- resolve_
config_ file - Resolves the path to an optional config file.
- resolve_
persist_ field - Resolves a persisted config field from stored values or read-only fallback sources.
- resolve_
readonly_ field - Resolves a read-only config field from environment, TOML, or a default.
Type Aliases
- Deserialize
Fallback - Function pointer used to parse legacy persisted values.
- External
Applier