pub struct PersistedField<T, V> { /* private fields */ }Expand description
Read, write, and subscribe access to a generated persisted settings field.
Implementations
Sourceimpl<T, V> PersistedField<T, V>
impl<T, V> PersistedField<T, V>
Sourceimpl<T, V> PersistedField<T, V>
impl<T, V> PersistedField<T, V>
Sourcepub fn set(&self, value: V) -> Result<(), SettingsError>
pub fn set(&self, value: V) -> Result<(), SettingsError>
Persists a new field value and updates the in-memory snapshot.
Sourceimpl<T, V> PersistedField<T, V>
impl<T, V> PersistedField<T, V>